@@ -1,4 +1,4 @@
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 import tensorflow_hub
 import tensorflow_text
 
@@ -10,8 +10,3 @@ def load_model(dir="/home/andrew/Models/universal-text"):
 
 def get_vecs(texts):
     return model["text"](texts)
-
-
-def get_vec(text):
-    return model["text"]([text])[0]
-
